Additional resources
====================

- The main memcached site explains the memcached architecture, and contains
  information on administering and tuning a memcached cluster.

  o http://www.danga.com/memcached/

- The Python client bindings for memcached are maintained by
  Sean Reifschneider at Tummy.com:

  o http://www.python.org/pypi/memcached/1.2_tummy6

- 'tugela' is an alternate cache daemon implementation, which stores
  its mapping using a Berkeley b-tree on disk.  It conforms to the same
  wire protocol as 'memcached':

  o http://meta.wikimedia.org/wiki/Tugela_Cache
